@@ -89,7 +89,6 @@ typedef struct opkg_conf {
     int autoremove;
     int ignore_uid;
     int force_depends;
-    int force_defaults;
     int force_maintainer;
     int ignore_maintainer;
     int force_overwrite;
@@ -204,6 +203,9 @@ int opkg_conf_get_option(char *option, void *value);
 int opkg_conf_set_option(const char *name, const char *value,
                          int overwrite);
 
+int opkg_lock(void);
+int opkg_unlock(void);
+
 char *opkg_solver_version_alloc(void);
 
 #ifdef __cplusplus
