@@ -924,7 +924,7 @@ static int libsolv_solver_execute_transaction(libsolv_solver_t *libsolv_solver)
     } else {
         pkg_t *pkg;
 
-        if (libsolv_solver_transaction_preamble(libsolv_solver, pkgs, transaction, 0)) {
+        if (libsolv_solver_transaction_preamble(libsolv_solver, pkgs, transaction, opkg_config->noaction)) {
             err = -1;
             goto CLEANUP;
         }
